@@ -1,7 +1,10 @@
 #' Impute missing values using either a specified method or through validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.impute}{\code{IAI.impute}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute}{\code{IAI.impute}}
+#'
+#' This function was deprecated in iai 1.7.0. This is for consistency with the
+#' IAI v3.0.0 Julia release.
 #'
 #' @param X The dataframe in which to impute missing values.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -10,6 +13,7 @@
 #'
 #' @export
 impute <- function(X, ...) {
+  lifecycle::deprecate_warn("1.7.0", "iai::impute()")
   jl_func("IAI.impute_convert", X, ...)
 }
 
@@ -17,7 +21,10 @@ impute <- function(X, ...) {
 #' Impute missing values using cross validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.impute_cv}{\code{IAI.impute_cv}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute_cv}{\code{IAI.impute_cv}}
+#'
+#' This function was deprecated in iai 1.7.0. This is for consistency with the
+#' IAI v3.0.0 Julia release.
 #'
 #' @param X The dataframe in which to impute missing values.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -26,6 +33,7 @@ impute <- function(X, ...) {
 #'
 #' @export
 impute_cv <- function(X, ...) {
+  lifecycle::deprecate_warn("1.7.0", "iai::impute()")
   jl_func("IAI.impute_cv_convert", X, ...)
 }
 
@@ -33,7 +41,7 @@ impute_cv <- function(X, ...) {
 #' Generic learner for imputing missing values
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.ImputationLearner}{\code{IAI.ImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ImputationLearner}{\code{IAI.ImputationLearner}}
 #'
 #' @param method (optional) Specifies the imputation method to use.
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
@@ -50,7 +58,7 @@ imputation_learner <- function(method = "opt_knn", ...) {
 #' Learner for conducting optimal k-NN imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.OptKNNImputationLearner}{\code{IAI.OptKNNImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptKNNImputationLearner}{\code{IAI.OptKNNImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -66,7 +74,7 @@ opt_knn_imputation_learner <- function(...) {
 #' Learner for conducting optimal SVM imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.OptSVMImputationLearner}{\code{IAI.OptSVMImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptSVMImputationLearner}{\code{IAI.OptSVMImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -82,7 +90,7 @@ opt_svm_imputation_learner <- function(...) {
 #' Learner for conducting optimal tree-based imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.OptTreeImputationLearner}{\code{IAI.OptTreeImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptTreeImputationLearner}{\code{IAI.OptTreeImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -98,7 +106,7 @@ opt_tree_imputation_learner <- function(...) {
 #' Learner for conducting heuristic k-NN imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.SingleKNNImputationLearner}{\code{IAI.SingleKNNImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.SingleKNNImputationLearner}{\code{IAI.SingleKNNImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -114,7 +122,7 @@ single_knn_imputation_learner <- function(...) {
 #' Learner for conducting mean imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.MeanImputationLearner}{\code{IAI.MeanImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.MeanImputationLearner}{\code{IAI.MeanImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -130,7 +138,7 @@ mean_imputation_learner <- function(...) {
 #' Learner for conducting random imputation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.2.0/OptImpute/reference/#IAI.RandImputationLearner}{\code{IAI.RandImputationLearner}}
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.RandImputationLearner}{\code{IAI.RandImputationLearner}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -141,3 +149,67 @@ mean_imputation_learner <- function(...) {
 rand_imputation_learner <- function(...) {
   set_obj_class(jl_func("IAI.RandImputationLearner_convert", ...))
 }
+
+
+#' Learner for conducting zero-imputation
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ZeroImputationLearner}{\code{IAI.ZeroImputationLearner}}
+#'
+#' @param ... Use keyword arguments to set parameters on the resulting learner.
+#'            Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{lnr <- iai::zero_imputation_learner()}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.0 or higher.
+#'
+#' @export
+zero_imputation_learner <- function(...) {
+  requires_iai_version("3.0.0", "zero_imputation_learner")
+  set_obj_class(jl_func("IAI.ZeroImputationLearner_convert", ...))
+}
+
+
+#' Fit an imputation learner with training features and create adaptive
+#' indicator features to encode the missing pattern
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.fit_and_expand!}{\code{IAI.fit_and_expand!}}
+#'
+#' @param lnr The learner to use for imputation.
+#' @param X The dataframe in which to impute missing values.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{lnr <- iai::fit_and_expand(lnr, X, type = "finite")}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.0 or higher.
+#'
+#' @export
+fit_and_expand <- function(lnr, X, ...) {
+  requires_iai_version("3.0.0", "fit_and_expand")
+  set_obj_class(jl_func("IAI.fit_and_expand_convert", lnr, X, ...))
+}
+
+
+#' Transform features with a trained imputation learner and create adaptive
+#' indicator features to encode the missing pattern
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.transform_and_expand}{\code{IAI.transform_and_expand}}
+#'
+#' @param lnr The learner to use for imputation.
+#' @param X The dataframe in which to impute missing values.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{lnr <- iai::transform_and_expand(lnr, X, type = "finite")}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.0 or higher.
+#'
+#' @export
+transform_and_expand <- function(lnr, X, ...) {
+  requires_iai_version("3.0.0", "transform_and_expand")
+  set_obj_class(jl_func("IAI.transform_and_expand_convert", lnr, X, ...))
+}
